<?php

abstract class ExpayBaseEvent
{
    protected $provider;

    public function __construct()
    {
        $this->provider = new ExpayProvider();
    }

    public abstract function handle($event);

    protected function sendResponse($code, $message)
    {
        $response = [
            'response' => [
                'status' => $code,
                'message' => $message,
                'timestamp' => time()
            ]
        ];
        $response['hash'] = $this->provider->hashResponse(json_encode($response['response']));
        header('Content-type: application/json');
        exit(json_encode($response));
    }

    /**
     * Check that the order exists in woocommerce
     *
     * @return bool
     */
    protected function isOrderValid($order)
    {
        return ($order ? true : false);
    }

    /**
     * Check that the order status is 'Canceled' in woocommerce
     *
     * @return bool
     */
    protected function isOrderCanceled($order)
    {
        return ($order->get_status() === 'canceled');
    }

    /**
     * Check that the order status is 'Accepted' in woocommerce
     *
     * @return bool
     */
    protected function isOrderPaid($order)
    {
        return ($order->get_status() === 'success');
    }

    /**
     * Check that the hash is valid
     *
     * @return bool
     */
    protected function isHashValid($event)
    {
        if (!isset($event['hash'])) {
            return false;
        }

        $hash = $event['hash'];
        unset($event['hash']);
        if ($hash !== $this->provider->hashResponse(http_build_query($event))) {
            return false;
        }

        return true;
    }

    /**
     * Check that the Woocommerce order amount matсhes amount from Expay Server
     *
     * @return bool
     */
    protected function amountMatching($order, $event)
    {
        return !($order->get_total() != $event['amount']);
    }
}
