<?php

defined('ABSPATH') or die('No direct script access allowed.');

require_once dirname(__FILE__) . '/ExpayBaseEvent.php';

class ExpayEventCheck extends ExpayBaseEvent
{

    public function handle($event)
    {
        $order = wc_get_order($event['order']);
        if (!$this->isOrderValid($order)) {
            error_log('Expay Webhooks: the ' . $event['order'] . ' order doesn\'t exist');
            $this->sendResponse(475, 'Payment with the specified parameters can not be processed');
            return false;
        }

        if (!$this->isHashValid($event)) {
            error_log('Expay Webhooks: invalid hash');
            $this->sendResponse(401, 'Invalid hash');
            return false;
        }

        if (!$this->amountMatching($order, $event)) {
            error_log('Expay Webhooks: The amount of order ' . $event['order'] . " doesn't match.");
            $this->sendResponse(475, 'Payment with the specified parameters can not be processed');
            return false;
        }

        if ($this->isOrderCanceled($order)) {
            error_log('Expay Webhooks: the order#' . $order->get_id() . ' has already been canceled');
            $this->sendResponse(475, 'Payment with the specified parameters can not be processed');
            return false;
        }

        if ($this->isOrderPaid($order)) {
            error_log('Expay Webhooks: the order#' . $order->get_id() . ' has already been paid');
            $this->sendResponse(475, 'Payment with the specified parameters can not be processed');
            return false;
        }

        $message = 'Expay Webhooks: check of order#' . $order->get_id() . ' is succeeded';
        error_log($message);

        $this->sendResponse(270, 'Account exist');

        return true;
    }
}
