<?php

defined('ABSPATH') or die('No direct script access allowed.');


class ExpayEventHandler
{
    private $order_id;
    private $provider;

    public function __construct($order_id)
    {
        $this->order_id = $order_id;
        $this->provider = new ExpayProvider();

        require_once dirname(__FILE__) . '/ExpayEventCheck.php';
        require_once dirname(__FILE__) . '/ExpayEventPay.php';
    }

    //todo
    protected function sendResponse($code, $message)
    {
        $response = [
            'response' => [
                'status' => $code,
                'message' => $message,
                'timestamp' => time()
            ]
        ];
        $response['hash'] = $this->provider->hashResponse(json_encode($response));
        header('Content-type: application/json');
        exit(json_encode($response));
    }

    public function handle($event)
    {
        error_log("Expay Webhooks: post request: " . json_encode($event));

        if (!isset($event['method'])) {
            error_log('Expay Webhooks: method not set. ' . 'Request:' . json_encode($event));
            $this->sendResponse(400, 'Expay Webhooks: method not set');
            return false;
        }

        switch ($event['method']) {
            case 'check':
                $message = 'Expay Webhooks: an event CHECK (order#' . $event['order'] . ') has been caught.';
                error_log($message);
                $expay_event = new ExpayEventCheck();
                break;

            case 'pay':
                $message = 'Expay Webhooks: an event PAY (order#' . $event['order'] . ') has been caught.';
                error_log($message);
                $expay_event = new ExpayEventPay();
                break;

            default:
                error_log('Expay Webhooks: unknown method: ' . $event['method']);
                $this->sendResponse(400, 'Expay Webhooks: unknown method: ' . $event['method']);
                return false;
        }

        return $expay_event->handle($event);
    }
}
