<?php

defined('ABSPATH') or die('No direct script access allowed.');


class ExpayEventPay extends ExpayBaseEvent
{
    public function handle($event)
    {
        $order = wc_get_order($event['order']);
        if (!$this->isHashValid($event)) {
            error_log('Expay Webhooks: invalid hash');
            $this->sendResponse(401, 'Invalid hash');
            return false;
        }

        if (!$this->isOrderValid($order)) {
            error_log('Expay Webhooks: the ' . $event['order'] . ' order doesn\'t exist');
            $this->sendResponse(475, 'Payment with the specified parameters can not be processed');
            return false;
        }

        if (!$this->amountMatching($order, $event)) {
            error_log('Expay Webhooks: The amount of order ' . $event['order'] . " doesn't match.");
            $this->sendResponse(475, 'Payment with the specified parameters can not be processed');
            return false;
        }

        if ($this->isOrderCanceled($order)) {
            error_log('Expay Webhooks: the order#' . $order->get_id() . ' has already been canceled');
            $this->sendResponse(475, 'Payment with the specified parameters can not be processed');
            return false;
        }

        if (!$this->isPaymentStatusSuccess($event)) {
            $message = 'Expay Webhooks: status of order#' . $event['order'] . 'change to "Canceled"';
            error_log($message);
            $order->update_status('canceled');
            $order->add_order_note('Payment canceled');
            $this->sendResponse(475, 'Payment with the specified parameters can not be processed');
            return false;
        }

        if ($this->isOrderPaid($order)) {
            error_log('Expay Webhooks: the order#' . $order->get_id() . ' has already been paid');
            $this->sendResponse(205, 'Payment success');
            return true;
        }

        //$order->update_status('success', 'Payment accepted');
        //$order->add_order_note('Payment accepted');
        $order->payment_complete();
        $message = 'Expay Webhooks: status of order#' . $order->get_id() . 'change to "Payment accepted"';
        error_log($message);

        $this->sendResponse(205, 'Payment success');
        return true;
    }

    /** Check the Payment status in Expay Server */
    private function isPaymentStatusSuccess($event)
    {
        $status = $this->provider->getPaymentStatus($event['id']);
        error_log('Invoice Status: ' . $status);
        if ($status != 203 && $status != 205) {
            $message = 'Expay Webhooks: The status of order #' . $event['order'] . ' in Expay server is not success.';
            error_log($message);
            return false;
        }
        return true;
    }
}
