<?php

defined('ABSPATH') or die('No direct script access allowed.');


class ExpayPayment
{
    private $provider;
    private $view_url;

    public function __construct($view_url)
    {
        $this->provider = new ExpayProvider();
        $this->view_url = $view_url;
    }

    private function generateSuccessRedirectUrl()
    {
        return $this->view_url . '?&status=success';
    }

    private function generateWaitingRedirectUrl()
    {
        return $this->view_url . '?&status=waiting';
    }

    private function generateRejectRedirectUrl()
    {
        return $this->view_url . '?&status=reject';
    }


    function initPayment($order_amount, $order_id, $payment_methods)
    {
        $attributes = [];
        $methodList = $payment_methods;
        foreach ($methodList as $method) {
            if ($method['alias'] === $_POST['expay-payment-method']) {
                $service_id = $method['id'];
                if (count($method['attributes']) != 0) {
                    foreach ($method['attributes'] as $attribute) {
                        if (!empty($_POST[$attribute['key']])) {
                            $attributes[$attribute['key']] = $_POST[$attribute['key']];
                        }
                    }
                }
                break;
            }
        }

        $response = $this->provider->initPayment(
            $service_id,
            $order_amount,
            $order_id,
            $this->generateSuccessRedirectUrl(),
            $this->generateWaitingRedirectUrl(),
            $this->generateRejectRedirectUrl(),
            $attributes
        );

        return $response;
    }


    function getPaymentUrl($response)
    {
        if (count($response['attributes']) != 0) {
            foreach ($response['attributes'] as $attribute) {
                switch ($attribute['key']) {
                    case 'redirectUrl':
                        return [
                            'key' => 'redirectUrl',
                            'src' => $attribute['value'],
                            'name' => $response['service']['name'],
                        ];
                    case 'qrcode':
                        return [
                            'key' => 'qrcode',
                            'src' => $attribute['value'],
                        ];
                    case 'receiptUrl': // PDF
                        return [
                            'key' => 'receiptUrl',
                            'src' => $attribute['value'],
                        ];
                        break;
                    default:
                        break;
                }
            }
        } else {
            return [
                'key' => 'offline',
                'src' => $this->generateWaitingRedirectUrl(),
            ];
        }
    }
}